/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __PAN_STATUS_ITEM__H__
#define __PAN_STATUS_ITEM__H__

#include <glib.h>
#include "pan-callback.h"
#include "pan-object.h"

/**
***  STATUS ITEM CLASS DEFINITION
**/

#define STATUS_ITEM(a) ((StatusItem *)a)

typedef struct _StatusItem StatusItem;
typedef gchar* (*StatusItemDescribeFunc)(const StatusItem*);

struct _StatusItem
{
	/*Parent*/
	PanObject pan_object;        /* parent object */

	/*Callbacks*/
	PanCallback* progress;       /* obj arg is int [0...100] */
	PanCallback* set_activity;   /* obj arg is int */
	PanCallback* status;         /* obj arg is const gchar* (don't free) */
	PanCallback* error;          /* obj arg is const gchar* (don't free) */
	PanCallback* done;           /* obj arg is status int */

	/*Fields*/
	gchar* last_error;           /* the last error emitted, or NULL */
	int progress_val;            /* value is [0...100] */
	int steps;                   /* number of steps for progress */
	int step;                    /* number of steps so far. [0..steps] */

	/* virtual functions */
	StatusItemDescribeFunc describe;
};


/**
***  PROTECTED
**/

void status_item_constructor    (StatusItem               * item,
                                 PanObjectDestructor        dtor,
                                 StatusItemDescribeFunc     describe);

void status_item_destructor     (PanObject                * object);


/**
***  PUBLIC
**/

StatusItem*   status_item_new                  (StatusItemDescribeFunc);

gchar*        status_item_describe             (const StatusItem * item);

void          status_item_emit_status          (StatusItem       * item,
                                                const gchar      * fmt,
                                                ...);

void          status_item_emit_error           (StatusItem       * item,
                                                const gchar      * fmt,
                                                ...);

void          status_item_emit_progress        (StatusItem       * item,
                                                gint               out_of_100);

void          status_item_emit_init_steps      (StatusItem       * item,
                                                gint               steps);

void          status_item_emit_next_step       (StatusItem       * item);

void          status_item_emit_set_step        (StatusItem       * item,
                                                gint               step);

void          status_item_emit_activity        (StatusItem       * item,
                                                gint               n);

void          status_item_emit_done            (StatusItem       * item,
                                                gint               status);

int           status_item_get_progress_of_100  (const StatusItem * item);

void          status_item_next_step_gfunc      (gpointer           group,
                                                gpointer           item);

#endif /* __PAN_STATUS_ITEM__H__ */
